==> I2P-Messenger_0.2.16_Beta_src.zip: I2P-Messenger/src/User.h <==
/***************************************************************************
 *   Copyright (C) 2008 by I2P-Messenger   				   *
 *   Messenger-Dev@I2P-Messenger   					   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef USER_H
#define USER_H

#include <QtGui>
#include <QStringList>
#include <QTime>
#include "I2PStream.h"
#include <QtGlobal>
namespace User
{
	enum CONNECTIONTOUSER{
		OFFLINE,
		ONLINE,
		TRYTOCONNECT,
		ERROR
	};

	enum ONLINESTATE{
		USERONLINE,
		USEROFFLINE,
		USERINVISIBLE,
		USERWANTTOCHAT,
		USERAWAY,
		USERDONT_DISTURB,
		USERTRYTOCONNECT,
		USERBLOCKEDYOU
	};

	enum RECIVEDINFOS{
		NICKNAME,
		GENDER,
		AGE,
		INTERESTS
	};

	struct CRecivedInfos{
		QString Nickname;
		QString Gender;
		qint32  Age;
		QString Interests;
	};

}//namespace user

using namespace User;
class CProtocol;
class CChatMessageChanger;
class CUser: public QObject
{
	
	
	

	Q_OBJECT
	public:
					CUser(	CProtocol& Protocol,
						QString Name,
						QString I2PDestination,
						qint32 I2PStream_ID
					);
					~CUser();
	
	const 	QString 		getName()const;
	const 	QString 		getI2PDestination()const;
	      	qint32  		getI2PStreamID()const;
	const 	QString 		getProtocolVersion()const;
		double			getProtocolVersion_D()const;
	const 	QString 		getClientName()const;
	const	QString 		getClientVersion()const;
	      	QColor  		getTextColor();
	      	QFont   		getTextFont();
		CONNECTIONTOUSER 	getConnectionStatus()const;
		ONLINESTATE 	 	getOnlineState()const;
	const 	QStringList&		getAllChatMessages();
	const	QStringList		getNewMessages(bool haveFocus);
	const	CRecivedInfos		getRecivedUserInfos()const;
	const   QString			getRecivedUserNickname()const;

	const	QString			getHighestUsableProtocolVersionFiletransfer();
		double			getHighestUsableProtocolVersionFiletransfer_D();
	const	QString			getMaxProtocolVersionFiletransfer(){return mMaxProtocolVersionFiletransfer;};
	 	double			getMaxProtocolVersionFiletransfer_D();
	const	QString			getMinProtocolVersionFiletransfer(){return mMinProtocolVersionFiletransfer;};
		double			getMinProtocolVersionFiletransfer_D();
		bool 			getHaveNewUnreadMessages();
		bool			getIsInvisible(){return mInvisible;};

		void 			setConnectionStatus(CONNECTIONTOUSER Status);
		void 			setOnlineState(const ONLINESTATE newState);
		void			setName(QString newName);
		void 			setI2PStreamID(qint32 ID);
		void 			setProtocolVersion(QString Version);
		void 			setClientName(QString Name);
		void 			setClientVersion(QString Version);
		void 			setTextColor(QColor textColor);
		void 			setTextFont(QFont textFont);
		void 			setInvisible(bool b);
		void 			setMaxProtocolVersionFiletransfer(QString Version){mMaxProtocolVersionFiletransfer=Version;};
		void 			setMinProtocolVersionFiletransfer(QString Version){mMinProtocolVersionFiletransfer=Version;};
		void			setRecivedUserInfos(RECIVEDINFOS Tag,QString value);
		void			setRecivedNicknameToUserNickname();
		void 			IncomingNewChatMessage(QString newMessage);
		void 			IncomingMessageFromSystem(QString newMessage);


	
	public slots:
		void  			slotSendChatMessage(QString Message);

	signals:
		void 			signOnlineStateChanged();
		void 			signNewMessageRecived();
		void 			signNewIncomingMessageRecived();
		void 			signConnectionOnline();
		void 			signConnectionOffline();
		void			signUserDeleted();
	private:
		void 			SendAllunsendedMessages();
		
		bool			mInvisible;
		bool			mRecivedNicknameToUserNickname;
		bool			mHaveNewUnreadMessages;

	const 	QString 		mI2PDestination;
		QString 		mName;
		qint32 			mI2PStream_ID;	

		CONNECTIONTOUSER 	mConnectionStatus;
		ONLINESTATE	 	mCurrentOnlineState;
		QString 		mProtocolVersion;
		QString			mMaxProtocolVersionFiletransfer;
		QString			mMinProtocolVersionFiletransfer;
		QString 		mClientName;
		QString 		mClientVersion;
		QStringList 		mAllMessages;
		QStringList		mNewMessages;
		QStringList 		mUnsendedMessages;
		CProtocol& 		mProtocol;
		CRecivedInfos		mRecivedUserInfos;

	//Settings for the chatwindow
		QColor 			mTextColor;
		QFont  			mTextFont;
	  	CChatMessageChanger&	mChatMessageChanger;
};

#endif

==> I2P-Messenger_0.2.19_Beta_src.zip: I2P-Messenger/src/User.h <==
/***************************************************************************
 *   Copyright (C) 2008 by I2P-Messenger   				   *
 *   Messenger-Dev@I2P-Messenger   					   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef USER_H
#define USER_H

#include <QtGui>
#include <QStringList>
#include <QTime>
#include "I2PStream.h"
#include <QtGlobal>
namespace User
{
	enum CONNECTIONTOUSER{
		OFFLINE,
		ONLINE,
		TRYTOCONNECT,
		ERROR
	};

	enum ONLINESTATE{
		USERONLINE,
		USEROFFLINE,
		USERINVISIBLE,
		USERWANTTOCHAT,
		USERAWAY,
		USERDONT_DISTURB,
		USERTRYTOCONNECT,
		USERBLOCKEDYOU
	};

	enum RECIVEDINFOS{
		NICKNAME,
		GENDER,
		AGE,
		INTERESTS
	};

	struct CRecivedInfos{
		QString Nickname;
		QString Gender;
		qint32  Age;
		QString Interests;
	};

}//namespace user

using namespace User;
class CCore;
class CProtocol;
class CChatMessageChanger;
class CUser: public QObject
{
	Q_OBJECT
	public:
					CUser(	CCore&	Core,
						CProtocol& Protocol,
						QString Name,
						QString I2PDestination,
						qint32 I2PStream_ID
					);
					~CUser();
	
	const 	QString 		getName()const;
	const 	QString 		getI2PDestination()const;
	      	qint32  		getI2PStreamID()const;
	const 	QString 		getProtocolVersion()const;
		double			getProtocolVersion_D()const;
	const 	QString 		getClientName()const;
	const	QString 		getClientVersion()const;
	      	QColor  		getTextColor();
	      	QFont   		getTextFont();
		CONNECTIONTOUSER 	getConnectionStatus()const;
		ONLINESTATE 	 	getOnlineState()const;
	const 	QStringList&		getAllChatMessages();
	const	QStringList		getNewMessages(bool haveFocus);
	const	CRecivedInfos		getRecivedUserInfos()const;
	const   QString			getRecivedUserNickname()const;

	const	QString			getHighestUsableProtocolVersionFiletransfer();
		double			getHighestUsableProtocolVersionFiletransfer_D();
	const	QString			getMaxProtocolVersionFiletransfer(){return mMaxProtocolVersionFiletransfer;};
	 	double			getMaxProtocolVersionFiletransfer_D();
	const	QString			getMinProtocolVersionFiletransfer(){return mMinProtocolVersionFiletransfer;};
		double			getMinProtocolVersionFiletransfer_D();
		bool 			getHaveNewUnreadMessages();
		bool			getIsInvisible(){return mInvisible;};
		bool			getUsedB32Dest(){return mUseB32Dest;};

		void 			setConnectionStatus(CONNECTIONTOUSER Status);
		void 			setOnlineState(const ONLINESTATE newState);
		void			setName(QString newName);
		void 			setI2PStreamID(qint32 ID);
		void 			setProtocolVersion(QString Version);
		void 			setClientName(QString Name);
		void 			setClientVersion(QString Version);
		void 			setTextColor(QColor textColor);
		void 			setTextFont(QFont textFont);
		void 			setInvisible(bool b);
		void 			setMaxProtocolVersionFiletransfer(QString Version){mMaxProtocolVersionFiletransfer=Version;};
		void 			setMinProtocolVersionFiletransfer(QString Version){mMinProtocolVersionFiletransfer=Version;};
		void			setRecivedUserInfos(RECIVEDINFOS Tag,QString value);
		void			setRecivedNicknameToUserNickname();
		void			setReplaceB32WithB64(QString b64Dest);
		void 			IncomingNewChatMessage(QString newMessage);
		void 			IncomingMessageFromSystem(QString newMessage);


	
	public slots:
		void  			slotSendChatMessage(QString Message);

	signals:
		void 			signOnlineStateChanged();
		void 			signNewMessageRecived();
		void 			signNewIncomingMessageRecived();
		void 			signConnectionOnline();
		void 			signConnectionOffline();
		void			signUserDeleted();
	private:
		CCore&			mCore;
		CProtocol& 		mProtocol;
		QString 		mName;
	const 	QString 		mI2PDestination;
		qint32 			mI2PStream_ID;	
		
		bool			mInvisible;
		bool			mRecivedNicknameToUserNickname;
		bool			mHaveNewUnreadMessages;
		CONNECTIONTOUSER 	mConnectionStatus;
		ONLINESTATE	 	mCurrentOnlineState;
		QString 		mProtocolVersion;
		QString			mMaxProtocolVersionFiletransfer;
		QString			mMinProtocolVersionFiletransfer;
		QString 		mClientName;
		QString 		mClientVersion;
		QStringList 		mAllMessages;
		QStringList		mNewMessages;
		QStringList 		mUnsendedMessages;
		
		CRecivedInfos		mRecivedUserInfos;
		bool			mUseB32Dest;

	//<Settings for the chatwindow>
		QColor 			mTextColor;
		QFont  			mTextFont;
	  	CChatMessageChanger&	mChatMessageChanger;
	//</Settings for the chatwindow>
		void 			SendAllunsendedMessages();
};
#endif
